@@ -3,8 +3,8 @@ package core_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
+	"github.com/stretchr/testify/assert"
 )
 
 func TestShell_OptionToArgSpecName(t *testing.T) {
