@@ -5,14 +5,14 @@ import "github.com/scaleway/scaleway-cli/v2/core"
 func CreateDeploymentPublicEndpoint() core.BeforeFunc {
 	return core.ExecStoreBeforeCmd(
 		"DEPLOYMENT",
-		"scw inference deployment create node-type=H100 accept-eula=true model-name=meta/llama-2-70b-chat:fp8 -w",
+		"scw inference deployment create node-type=H100 accept-eula=true model-name=mistral/mistral-7b-instruct-v0.3:bf16 -w",
 	)
 }
 
 func CreateDeploymentPrivateEndpoint() core.BeforeFunc {
 	return core.ExecStoreBeforeCmd(
 		"DEPLOYMENT",
-		"scw inference deployment create node-type=H100 accept-eula=true model-name=meta/llama-2-70b-chat:fp8 endpoints.0.private-network.private-network-id={{ .PN.ID }} -w",
+		"scw inference deployment create node-type=H100 accept-eula=true model-name=mistral/mistral-7b-instruct-v0.3:bf16 endpoints.0.private-network.private-network-id={{ .PN.ID }} -w",
 	)
 }
 
