@@ -3,7 +3,6 @@ package instance_test
 import (
 	"testing"
 
-	"github.com/alecthomas/assert"
 	"github.com/scaleway/scaleway-cli/v2/core"
 	"github.com/scaleway/scaleway-cli/v2/internal/interactive"
 	block "github.com/scaleway/scaleway-cli/v2/internal/namespaces/block/v1alpha1"
@@ -11,6 +10,7 @@ import (
 	"github.com/scaleway/scaleway-cli/v2/internal/testhelpers"
 	instanceSDK "github.com/scaleway/scaleway-sdk-go/api/instance/v1"
 	"github.com/scaleway/scaleway-sdk-go/scw"
+	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
 
@@ -154,7 +154,7 @@ func Test_ServerAction(t *testing.T) {
 					Zone:     storedServer.Zone,
 					ServerID: storedServer.ID,
 				})
-				assert.Nil(t, err)
+				require.NoError(t, err)
 				assert.Equal(t, instanceSDK.ServerStateRunning, resp.Server.State)
 			},
 			core.TestCheckGolden(),
